@@ -229,6 +229,7 @@ sub run {
               }xsm
         ) {
             # All of these indirectly use dh.
+            $seencommand = 1;
             $build_systems{'dh'} = 1;
             delete($build_systems{'debhelper'});
         } elsif (
@@ -355,6 +356,10 @@ sub run {
           if $line and $level >= 11;
     }
 
+    my $num_overrides = scalar(keys %overrides);
+    tag 'excessive-debhelper-overrides', $num_overrides
+      if $num_overrides >= 20;
+
     tag 'debian-rules-uses-unnecessary-dh-argument', 'dh ... --parallel',
       "(line $seen_dh_parallel)"
       if $seen_dh_parallel and $level >= 10;
